@@ -24,8 +24,8 @@
  * CSV̲
  *
  * $RCSfile: result.php,v $
- * $Revision: 1.8 $
- * $Date: 2013/09/05 06:08:29 $
+ * $Revision: 1.11 $
+ * $Date: 2014/01/24 02:48:59 $
  **********************************************************/
 
 include_once("../../initial");
@@ -365,6 +365,7 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
         }
     }
 
+    /* ɲû */
     if ($type == ADD_MODE) {
         /* LDAPɲ */
         if (isset($_POST["upload"])) {
@@ -381,17 +382,19 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
                     return CSV_BATCH_NG_END;
                 }
             }
+            $err_msg = $msgarr['14005'][SCREEN_MSG];
+            $log_msg = $msgarr['14005'][LOG_MSG];
+        /* եå */
+        } else {
+            $err_msg = $msgarr['14014'][SCREEN_MSG];
+            $log_msg = $msgarr['14014'][LOG_MSG];
         }
-
-        /* Ͽ */
-        $err_msg = $msgarr['14005'][SCREEN_MSG];
-        $log_msg = $msgarr['14005'][LOG_MSG];
         printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
         result_log($logstr . ":OK:" . $userdata["uid"] .
                    ":$log_msg(line ${line})");
-
+    /* ѹ */
     } else {
         // LDAPѹ
         if (isset($_POST["upload"])) {
@@ -408,11 +411,13 @@ function csv_add_user($userdata, $ds, $fcheckuser, $logstr, $line)
                     return CSV_BATCH_NG_END;
                 }
             }
+            $err_msg = $msgarr['14006'][SCREEN_MSG];
+            $log_msg = $msgarr['14006'][LOG_MSG];
+        /* եå */
+        } else {
+            $err_msg = $msgarr['14015'][SCREEN_MSG];
+            $log_msg = $msgarr['14015'][LOG_MSG];
         }
-
-        /* ѹ */
-        $err_msg = $msgarr['14006'][SCREEN_MSG];
-        $log_msg = $msgarr['14006'][LOG_MSG];
         printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
         ob_flush();
         flush();
@@ -520,11 +525,15 @@ function csv_del_user($userdata, $ds, $fcheckuser, $logstr, $line)
                 return CSV_BATCH_NG_END;
             }
         }
+        $err_msg = $msgarr['14008'][SCREEN_MSG];
+        $log_msg = $msgarr['14008'][LOG_MSG];
+    /* å */
+    } else {
+        $err_msg = $msgarr['14016'][SCREEN_MSG];
+        $log_msg = $msgarr['14016'][LOG_MSG];
     }
 
     /*  */
-    $err_msg = $msgarr['14008'][SCREEN_MSG];
-    $log_msg = $msgarr['14008'][LOG_MSG];
     printf(CSV_OK_MSG, $line, htmlspecialchars($userdata["uid"]), $err_msg);
     ob_flush();
     flush();
